@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.660001';
+$App::pherkin::VERSION = '0.68';
 use strict;
 use warnings;
 
@@ -26,6 +26,7 @@ has 'tags'       => ( is => 'rw', isa => ArrayRef, required => 0 );
 has 'tag_scheme' => ( is => 'rw', isa => ArrayRef, required => 0 );
 has 'match_only' => ( is => 'rw', isa => Bool,     default => 0 );
 has 'matching'   => ( is => 'rw', isa => Str,      default => 'first');
+has 'strict'     => ( is => 'rw', isa => Bool,     default => 0 );
 
 has 'harness' => ( is => 'rw' );
 
@@ -35,7 +36,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.660001
+version 0.68
 
 =head1 SYNOPSIS
 
@@ -125,7 +126,20 @@ sub _run_tests {
     $executor->execute( $_, $harness, $tag_spec ) for @features;
 
     $harness->shutdown();
-    return $harness->result;
+
+    my $exit_code = 0;
+    my $result = $harness->result;
+    if ($result eq 'failing') {
+        $exit_code = 2;
+    }
+    elsif ($self->strict) {
+        if ($result eq 'pending'
+            or $result eq 'undefined') {
+            $exit_code = 1;
+        }
+    }
+
+    return $exit_code;
 }
 
 sub _initialize_harness {
@@ -259,17 +273,18 @@ sub _process_arguments {
         debug_profiles => ['debug-profiles'],
 
         # Standard
-        help       => ['h|help|?'],
+        help       => [ 'h|help|?' ],
         includes   => [ 'I=s@', [] ],
-        lib        => ['l|lib'],
-        blib       => ['b|blib'],
-        output     => ['o|output=s'],
+        lib        => [ 'l|lib' ],
+        blib       => [ 'b|blib' ],
+        output     => [ 'o|output=s' ],
+        strict     => [ 'strict' ],
         steps      => [ 's|steps=s@', [] ],
         tags       => [ 't|tags=s@', [] ],
-        i18n       => ['i18n=s'],
+        i18n       => [ 'i18n=s' ],
         extensions => [ 'e|extension=s@', [] ],
         matching   => [ 'matching=s' ],
-        match_only => ['m|match'],
+        match_only => [ 'm|match' ],
     );
 
     GetOptions(
@@ -419,6 +434,9 @@ sub _process_arguments {
     # Match only?
     $self->match_only( $deref->('match_only') );
 
+    $self->strict( $deref->('strict') )
+        if $deref->('strict');
+
     return ( pop @ARGV );
 }
 
