@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.660001';
+$Test::BDD::Cucumber::Executor::VERSION = '0.68';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.660001
+version 0.68
 
 =head1 DESCRIPTION
 
@@ -26,13 +26,14 @@ use Number::Range;
 use Carp qw/croak/;
 our @CARP_NOT;
 
-use Test2::API qw/intercept context/;
+use Test2::API qw/intercept/;
 
 # Use-ing the formatter results in a
 # 'loaded too late to be used globally' warning
 # But we only need it locally anyway.
 require Test2::Formatter::TAP;
 
+use Test2::Tools::Basic qw/ pass fail done_testing /;
 # Needed for subtest() -- we don't want to import all its functions though
 require Test::More;
 
@@ -601,8 +602,9 @@ sub dispatch {
         ###TODO: Both intercept() and Test::More::subtest() should
         # be replaced by a specific Hub implementation for T::B::C
         Test::More::subtest( 'execute step', sub {
-            my $ctx = context();
-            $ctx->pass( "Starting to execute step: " . $context->text );
+            pass(
+                "Starting to execute step: " . $context->text
+                );
 
             # Take a copy of this. Turns out actually matching against it
             # directly causes all sorts of weird-ass heisenbugs which mst has
@@ -631,11 +633,10 @@ sub dispatch {
                 $coderef->($context)
             };
             if ($@) {
-                $ctx->fail("Step ran successfully", $@);
+                fail("Step ran successfully", $@);
             }
 
-            $ctx->done_testing;
-            $ctx->release;
+            done_testing();
                              });
     };
 
