@@ -1,10 +1,10 @@
 package Test::BDD::Cucumber::I18N::Data;
-$Test::BDD::Cucumber::I18N::Data::VERSION = '0.660001';
+$Test::BDD::Cucumber::I18N::Data::VERSION = '0.68';
 use strict;
 use warnings;
 use utf8;
 
-use JSON::MaybeXS qw/from_json/;
+use JSON::MaybeXS qw/JSON/;
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Test::BDD::Cucumber::I18N::Data - Cucumber language definitions
 
 =head1 VERSION
 
-version 0.660001
+version 0.68
 
 =head1 DESCRIPTION
 
@@ -54,13 +54,13 @@ L<The license on that file/project|https://github.com/cucumber/cucumber/blob/mas
 
 =head2 language_definitions
 
-Load and C<from_json> the language definitions.
+Load and C<decode_json> the language definitions.
 
 =cut
 
 sub language_definitions {
     my $raw = join '', (<DATA>);
-    my $langdefs = from_json($raw);
+    my $langdefs = JSON()->new->decode($raw);
     for my $lang (values %$langdefs) {
        for my $keyword (keys %{$lang}) {
           $lang->{$keyword} = join '|', @{$lang->{$keyword}}
